@@ -4,10 +4,11 @@ Made by Dorukyum on GitHub
 """
 
 from .chatbot import *
-from .prefixes import *
+from .database import *
 from .status import *
 from .webhooks import *
 from .requests import *
+from .embed import *
 
 __author__ = "Dorukyum"
 __license__ = "MIT"
